#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_HPP_INCLUDED

#include <nt2/operator/include/functions/scalar/is_equal.hpp>

#endif
